﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Media.Imaging;
using System.IO;
using Ozeki.Media;
using System.Windows.Forms;
using System.Windows.Threading;
using System.Linq;
using System.Diagnostics;
/// <summary>
//Based on blog post from Chris van Beek
/// </summary>
namespace BenCapCam
{

    public partial class LivePage : Window
    {
        private IpCamController _controller;
        public bool plzcap = true;
        public BitmapImage SnapShot { get; private set; }
        private Records Record;
        private DispatcherTimer MyTime;

        /***************************************************************
         *Function: LivePage
         *Parameters: null
         *Results: Iniatializes live page and set the timer for PicSave 
         *****************************************************************/
        public LivePage()
        {
            InitializeComponent();
            MyTime = new DispatcherTimer();
            MyTime.Tick += DispatcherTimer_Tick;
            MyTime.Interval = new TimeSpan(0, 0, 5);//hours minutes seconds
            MyTime.Start();
            this.Loaded += MainWindow_Loaded;
            this.Closing += MainWindow_Closing;
        }
        /******************************************************************
         *Funciton: DispatcherTimer_Tick
         *Parameters: object sender, EventArgs e
         *Results: On appropriate timer tick calls ScreenSnapShot 
         ******************************************************************/
        private void DispatcherTimer_Tick(object sender, EventArgs e)
        {
            ScreenSnapShot();
        }
        /********************************************************************
         *Function: MainWindow_Closing
         *Parameters: object sender, system.componentmodel.cancelEventArgs e
         *Results: Closes controller 
         ********************************************************************/
        void MainWindow_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            _controller.StopProcessing();
        }
        /************************************************************************
         *Function: MainWindow_Loaded
         *Parameters:object sender, RoutedEventArgs e
         *Results: creates and starts processing a new IpCamController 
         ************************************************************************/
        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            _controller = new IpCamController("http://192.168.1.2", "capcamera", "capcamera1");
            _controller.ImageReady += dec_FrameReady;
            _controller.StartProcessing();
        }

        public static explicit operator LivePage(AutomaticMultiPartReader v)
        {
            throw new NotImplementedException();
        }
        //keeps stream going
        void dec_FrameReady(object sender, ImageReadyEventArsgs args)
        {
            Live_Stream.Source = args.Image;
        }
        //used when user wants to take snapshot manually
        private void Snap_btn_Click(object sender, RoutedEventArgs e)
        {
            _controller.PicSave();
            System.Windows.MessageBox.Show("Snapshot Taken");
        }
        //used by timer to take Screenshots
        public void ScreenSnapShot()
        {
            if (plzcap == true)
                _controller.PicSave();
        }
        //Used for manually moving camera
        //**************************************************************
        private void L_btn_Click(object sender, RoutedEventArgs e)
        {
            
                _controller.PanLeft();
        }

        private void button_Click(object sender, RoutedEventArgs e)
        {
            _controller.PanRight();
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            _controller.PanUp();
        }

        private void button2_Click(object sender, RoutedEventArgs e)
        {
            _controller.PanDown();
        }
        //***************************************************************
        /*
         *Function: M_btn_Click
         *Parameters: object sender, routedeventargs e
         *Results: Opens records so faces found can be viewed 
         ****************************************************************/
        private void M_btn_Click(object sender, RoutedEventArgs e)
        {
            Record = new Records();
            Record.Show();
            string[] fileEntries = Directory.GetFiles("C:/Users/bpt-g/Desktop/capcamdetected");
            foreach (string fileName in fileEntries)
            {
                Record.Addlines(fileName + '\n');
            }
        }
        //Start and Stops the video feed
        //**************************************************************************
        private void StartVideoFeed_btn_Click(object sender, RoutedEventArgs e)
        {
            _controller.StartVideoFeedAgain();
            plzcap = true;
        }

        private void StopVideoFeed_btn_Click(object sender, RoutedEventArgs e)
        {
            _controller.StopProcessing2();
            plzcap = false;
        }
        //**************************************************************************
        /*
         *Function: StartProcessing_btn_Click
         *Parameters: object sender,routedeventargs e
         *Result: Starts Derecks program on loop through all images 
         */
        private void StartProcessing_btn_Click(object sender, RoutedEventArgs e)
        {
            string[] fileEntries = Directory.GetFiles("C:/Users/bpt-g/Desktop/capcam");
            foreach (string fileNamefldr in fileEntries)
            {
                var myProcess = new Process { StartInfo = new ProcessStartInfo("face-recognition") };
                myProcess.Start();
                myProcess.WaitForExit();
            }
        }
    }
}
